summaryrefslogtreecommitdiff
path: root/framework/source/jobs/jobdispatch.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/jobs/jobdispatch.cxx')
-rw-r--r--framework/source/jobs/jobdispatch.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/jobs/jobdispatch.cxx b/framework/source/jobs/jobdispatch.cxx
index 8f411435a107..d18ae515fc57 100644
--- a/framework/source/jobs/jobdispatch.cxx
+++ b/framework/source/jobs/jobdispatch.cxx
@@ -117,11 +117,11 @@ JobDispatch::JobDispatch( /*IN*/ const css::uno::Reference< css::lang::XMultiSer
//________________________________
/**
@short let this instance die
- @descr We have to release all used ressources and free used memory.
+ @descr We have to release all used resources and free used memory.
*/
JobDispatch::~JobDispatch()
{
// release all used ressources
m_xSMGR = css::uno::Reference< css::lang::XMultiServiceFactory >();
m_xFrame = css::uno::Reference< css::frame::XFrame >();
}
@@ -117,11 +117,11 @@ JobDispatch::JobDispatch( /*IN*/ const css::uno::Reference< css::lang::XMultiSer
JobDispatch::~JobDispatch()
{
- // release all used ressources
+ // release all used resources
m_xSMGR = css::uno::Reference< css::lang::XMultiServiceFactory >();
m_xFrame = css::uno::Reference< css::frame::XFrame >();